==> pass_mtx-0.0.20.tar.gz: test/pass_mtx_test.dart <==
/*
#################################################################################
#                                                                               #
#                     COPYRIGHT (C) DATABANK LLC since 2017                     #
#                                                                               #
#          ALL RIGHTS RESERVED BY DATABANK LLC.  THIS PROGRAM MUST BE           #
#          USED SOLELY FOR THE PURPOSES OF DATABANK LLC AND ITS USERS.          #
#   NO PART OF THIS PROGRAM MAY BE MODIFIED IN SOURCE OR BINARY FORM BY OTHERS  #
#             WITHOUT THE PRIOR WRITTEN PERMISSION OF DATABANK LLC.             #
#                                                                               #
#     USE OF COPYRIGHT NOTICE DOES NOT EVIDENCE PUBLICATION OF THE PROGRAM.     #
#                                                                               #
#################################################################################
*/

import 'package:flutter_test/flutter_test.dart';
import 'package:pass_mtx/pass_mtx.dart';
import 'package:pass_mtx/pass_mtx_platform_interface.dart';
import 'package:pass_mtx/pass_mtx_method_channel.dart';
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

class MockPassMtxPlatform
    with MockPlatformInterfaceMixin
    implements PassMtxPlatform {
  @override
  Future<String?> getPlatformVersion() => Future.value('42');

  @override
  Future<String?> getPassPing() => Future.value('Pong');
  @override
  Future<String?> getPassVersion() => Future.value('0.0.1');

  @override
  Future<String?> init(
          String appId, String clientId, String privatePem, String publicPem) =>
      Future.value('ok');

  @override
  Future<String?> initProd(
          String appId, String clientId, String privatePem, String publicPem) =>
      Future.value('ok');
  @override
  Future<String?> getCard(String userId) => Future.value('ok');
  @override
  Future<String?> deleteCard(String userId) => Future.value('ok');
  @override
  Future<String?> saveCard(String userId, String szPan, String cvv,
          String expDate, String cardHolderName) =>
      Future.value('ok');
  @override
  Future<String?> verifyCard(
          String userId, String verificationMethod, String verficationValue) =>
      Future.value('ok');

  @override
  Future<String?> purchase(
          String userId,
          String orderId,
          String paymentToken,
          String expDate,
          String paymentAmount,
          String dbRefNo,
          String description) =>
      Future.value('ok');

  @override
  Future<String?> passGetQr(String userId, String orderId, String paymentToken,
          String expDate, String ttl) =>
      Future.value('ok');

  @override
  Future<String?> orderEnquery(String userId, String orderId) =>
      Future.value('ok');

  @override
  Future<String?> orderConfirm(String userId, String orderId,
          String confirmMethod, String confirmResult) =>
      Future.value('ok');

  @override
  Future<String?> orderCancel(String userId, String orderId) =>
      Future.value('ok');

  @override
  Future<String?> enquery(String orderId) => Future.value('ok');
}

void main() {
  final PassMtxPlatform initialPlatform = PassMtxPlatform.instance;

  test('$MethodChannelPassMtx is the default instance', () {
    expect(initialPlatform, isInstanceOf<MethodChannelPassMtx>());
  });

  test('getPlatformVersion', () async {
    PassMtx passMtxPlugin = PassMtx();
    MockPassMtxPlatform fakePlatform = MockPassMtxPlatform();
    PassMtxPlatform.instance = fakePlatform;

    expect(await passMtxPlugin.getPlatformVersion(), '42');
    expect(await passMtxPlugin.getPassPing(), 'pong');
    expect(await passMtxPlugin.getPassVersion(), '0.0.1');
    expect(await passMtxPlugin.init("1", "2", "3", "4"), 'ok');
    expect(await passMtxPlugin.initProd("1", "2", "3", "4"), 'ok');
    expect(await passMtxPlugin.getCard("1"), 'ok');
    expect(await passMtxPlugin.deleteCard("1"), 'ok');
    expect(await passMtxPlugin.verifyCard("1", "2", "3"), 'ok');
    expect(await passMtxPlugin.passGetQr("1", "2", "3", "4", "5"), 'ok');
    expect(await passMtxPlugin.orderConfirm("1", "2"), 'ok');
    expect(await passMtxPlugin.orderEnquery("1", "2"), 'ok');
    expect(await passMtxPlugin.orderCancel("1", "2"), 'ok');
  });
}

==> pass_mtx-0.0.21.tar.gz: test/pass_mtx_test.dart <==
/*
#################################################################################
#                                                                               #
#                     COPYRIGHT (C) DATABANK LLC since 2017                     #
#                                                                               #
#          ALL RIGHTS RESERVED BY DATABANK LLC.  THIS PROGRAM MUST BE           #
#          USED SOLELY FOR THE PURPOSES OF DATABANK LLC AND ITS USERS.          #
#   NO PART OF THIS PROGRAM MAY BE MODIFIED IN SOURCE OR BINARY FORM BY OTHERS  #
#             WITHOUT THE PRIOR WRITTEN PERMISSION OF DATABANK LLC.             #
#                                                                               #
#     USE OF COPYRIGHT NOTICE DOES NOT EVIDENCE PUBLICATION OF THE PROGRAM.     #
#                                                                               #
#################################################################################
*/

import 'package:flutter_test/flutter_test.dart';
import 'package:pass_mtx/pass_mtx.dart';
import 'package:pass_mtx/pass_mtx_platform_interface.dart';
import 'package:pass_mtx/pass_mtx_method_channel.dart';
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

class MockPassMtxPlatform
    with MockPlatformInterfaceMixin
    implements PassMtxPlatform {
  @override
  Future<String?> getPlatformVersion() => Future.value('42');

  @override
  Future<String?> getPassPing() => Future.value('Pong');
  @override
  Future<String?> getPassVersion() => Future.value('0.0.1');

  @override
  Future<String?> init(
          String appId, String clientId, String privatePem, String publicPem) =>
      Future.value('ok');

  @override
  Future<String?> initProd(
          String appId, String clientId, String privatePem, String publicPem) =>
      Future.value('ok');
  @override
  Future<String?> getCard(String userId) => Future.value('ok');
  @override
  Future<String?> deleteCard(String userId) => Future.value('ok');
  @override
  Future<String?> saveCard(String userId, String szPan, String cvv,
          String expDate, String cardHolderName) =>
      Future.value('ok');
  @override
  Future<String?> verifyCard(
          String userId, String verificationMethod, String verficationValue) =>
      Future.value('ok');

  @override
  Future<String?> purchase(
          String userId,
          String orderId,
          String paymentToken,
          String expDate,
          String paymentAmount,
          String dbRefNo,
          String description) =>
      Future.value('ok');

  @override
  Future<String?> passGetQr(String userId, String orderId, String paymentToken,
          String expDate, String ttl) =>
      Future.value('ok');

  @override
  Future<String?> orderEnquery(String userId, String orderId) =>
      Future.value('ok');

  @override
  Future<String?> orderConfirm(
          String userId,
          String orderId,
          String confirmMethod,
          String confirmResult,
          String payToken,
          String expDate) =>
      Future.value('ok');

  @override
  Future<String?> orderCancel(String userId, String orderId) =>
      Future.value('ok');

  @override
  Future<String?> enquery(String orderId) => Future.value('ok');
}

void main() {
  final PassMtxPlatform initialPlatform = PassMtxPlatform.instance;

  test('$MethodChannelPassMtx is the default instance', () {
    expect(initialPlatform, isInstanceOf<MethodChannelPassMtx>());
  });

  test('getPlatformVersion', () async {
    PassMtx passMtxPlugin = PassMtx();
    MockPassMtxPlatform fakePlatform = MockPassMtxPlatform();
    PassMtxPlatform.instance = fakePlatform;

    expect(await passMtxPlugin.getPlatformVersion(), '42');
    expect(await passMtxPlugin.getPassPing(), 'pong');
    expect(await passMtxPlugin.getPassVersion(), '0.0.1');
    expect(await passMtxPlugin.init("1", "2", "3", "4"), 'ok');
    expect(await passMtxPlugin.initProd("1", "2", "3", "4"), 'ok');
    expect(await passMtxPlugin.getCard("1"), 'ok');
    expect(await passMtxPlugin.deleteCard("1"), 'ok');
    expect(await passMtxPlugin.verifyCard("1", "2", "3"), 'ok');
    expect(await passMtxPlugin.passGetQr("1", "2", "3", "4", "5"), 'ok');
    expect(
        await passMtxPlugin.orderConfirm("1", "2", "3", "4", "5", "6"), 'ok');
    expect(await passMtxPlugin.orderEnquery("1", "2"), 'ok');
    expect(await passMtxPlugin.orderCancel("1", "2"), 'ok');
  });
}
